TIRE-cpd toolbox 
===============================

Toolbox for time-invariant representation autoencoder approach (TIRE) for change point detection (CPD) task. Including three models: TIRE model with diamond loss [1], multi-channel TIRE model [2], and multi-view TIRE model [3].

The authors of these papers are:

- [Zhenxiang Cao](https://www.esat.kuleuven.be/stadius/person.php?id=2380) ([STADIUS](https://www.esat.kuleuven.be/stadius/), Dept. Electrical Engineering, KU Leuven)
- [Nick Seeuws](https://www.esat.kuleuven.be/stadius/person.php?id=2318) ([STADIUS](https://www.esat.kuleuven.be/stadius/), Dept. Electrical Engineering, KU Leuven)
- [Maarten De Vos](https://www.esat.kuleuven.be/stadius/person.php?id=203) ([STADIUS](https://www.esat.kuleuven.be/stadius/), Dept. Electrical Engineering, KU Leuven and Dept. Development and Regeneration, KU Leuven)
- [Alexander Bertrand](https://www.esat.kuleuven.be/stadius/person.php?id=331) ([STADIUS](https://www.esat.kuleuven.be/stadius/), Dept. Electrical Engineering, KU Leuven)

All authors are affiliated to [LEUVEN.AI - KU Leuven Institute for AI](https://ai.kuleuven.be). 


References
------------
[1] Cao, Z., Seeuws, N., De Vos, M. and Bertrand, A., 2023. A novel loss for change point detection models with time-invariant representations. IEEE Signal Processing Letters, 30, pp.1737-1741.
[2] Cao, Z., Seeuws, N., De Vos, M. and Bertrand, A., 2023. Change Point Detection in Multi-Channel Time Series Via a Time-Invariant Representation. IEEE Transactions on Knowledge and Data Engineering.
[3] Cao, Z., Seeuws, N., De Vos, M. and Bertrand, A., 2024. A Multi-view Extension for Change Point Detection via Time-invariant Representations. Proceedings of EUSIPCO 2024.